#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = __importDefault(require("node:path"));
const node_util_1 = require("node:util");
const help_1 = require("./help");
const config_1 = require("./util/config");
const reporters_1 = __importDefault(require("./reporters"));
const _1 = require(".");
const { values: { help, cwd: cwdArg, config = 'knip.json', only = [], exclude = [], 'no-progress': noProgress = false, reporter = 'symbols', jsdoc = [], 'max-issues': maxIssues = '1', }, } = (0, node_util_1.parseArgs)({
    options: {
        help: { type: 'boolean' },
        cwd: { type: 'string' },
        config: { type: 'string', short: 'c' },
        only: { type: 'string', multiple: true },
        exclude: { type: 'string', multiple: true },
        'no-progress': { type: 'boolean' },
        reporter: { type: 'string' },
        jsdoc: { type: 'string', multiple: true },
        'max-issues': { type: 'string' },
    },
});
if (help) {
    (0, help_1.printHelp)();
    process.exit(0);
}
const cwd = cwdArg ? node_path_1.default.resolve(cwdArg) : process.cwd();
const configuration = (0, config_1.importConfig)(cwd, config);
if (!configuration) {
    (0, help_1.printHelp)();
    process.exit(1);
}
const isShowProgress = noProgress !== false || (process.stdout.isTTY && typeof process.stdout.cursorTo === 'function');
const report = reporter in reporters_1.default ? reporters_1.default[reporter] : require(node_path_1.default.join(cwd, reporter));
const main = async () => {
    const resolvedConfig = (0, config_1.resolveConfig)(configuration, cwdArg);
    if (!resolvedConfig) {
        (0, help_1.printHelp)();
        process.exit(1);
    }
    const config = Object.assign({}, resolvedConfig, {
        cwd,
        include: (0, config_1.resolveIncludedFromArgs)(only, exclude),
        isShowProgress,
        jsDocOptions: {
            isReadPublicTag: jsdoc.includes('public'),
        },
    });
    const { issues, counters } = await (0, _1.run)(config);
    report({ issues, cwd, config });
    if (counters.files > Number(maxIssues))
        process.exit(counters.files);
};
main();
