"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_path_1 = __importDefault(require("node:path"));
const logIssueLine = (cwd, filePath, symbols) => {
    console.log(`${node_path_1.default.relative(cwd, filePath)}${symbols ? `: ${symbols.join(', ')}` : ''}`);
};
const logIssueGroupResult = (issues, cwd, title) => {
    title && console.log(`--- ${title} (${issues.length})`);
    if (issues.length) {
        issues.sort().forEach(filePath => logIssueLine(cwd, filePath));
    }
    else {
        console.log('N/A');
    }
};
const logIssueGroupResults = (issues, cwd, title) => {
    title && console.log(`--- ${title} (${issues.length})`);
    if (issues.length) {
        const sortedByFilePath = issues.sort((a, b) => (a.filePath > b.filePath ? 1 : -1));
        sortedByFilePath.forEach(({ filePath, symbols }) => logIssueLine(cwd, filePath, symbols));
    }
    else {
        console.log('N/A');
    }
};
exports.default = ({ issues, config, cwd }) => {
    const { include } = config;
    const reportMultipleGroups = Object.values(include).filter(Boolean).length > 1;
    if (include.files) {
        const unreferencedFiles = Array.from(issues.files);
        logIssueGroupResult(unreferencedFiles, cwd, reportMultipleGroups && 'UNREFERENCED FILES');
    }
    if (include.exports) {
        const unreferencedExports = Object.values(issues.exports).map(issues => {
            const items = Object.values(issues);
            return { ...items[0], symbols: items.map(i => i.symbol) };
        });
        logIssueGroupResults(unreferencedExports, cwd, reportMultipleGroups && 'UNREFERENCED EXPORTS');
    }
    if (include.nsExports) {
        const unreferencedNsExports = Object.values(issues.nsExports).map(issues => {
            const items = Object.values(issues);
            return { ...items[0], symbols: items.map(i => i.symbol) };
        });
        logIssueGroupResults(unreferencedNsExports, cwd, reportMultipleGroups && 'UNREFERENCED EXPORTS IN NAMESPACE');
    }
    if (include.types) {
        const unreferencedTypes = Object.values(issues.types).map(issues => {
            const items = Object.values(issues);
            return { ...items[0], symbols: items.map(i => i.symbol) };
        });
        logIssueGroupResults(unreferencedTypes, cwd, reportMultipleGroups && 'UNREFERENCED TYPES');
    }
    if (include.nsTypes) {
        const unreferencedNsTypes = Object.values(issues.nsTypes).map(issues => {
            const items = Object.values(issues);
            return { ...items[0], symbols: items.map(i => i.symbol) };
        });
        logIssueGroupResults(unreferencedNsTypes, cwd, reportMultipleGroups && 'UNREFERENCED TYPES IN NAMESPACE');
    }
    if (include.duplicates) {
        const unreferencedDuplicates = Object.values(issues.duplicates)
            .map(issues => Object.values(issues))
            .flat();
        logIssueGroupResults(unreferencedDuplicates, cwd, reportMultipleGroups && 'DUPLICATE EXPORTS');
    }
};
