"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getType = exports.partitionSourceFiles = exports.createProject = void 0;
const promises_1 = __importDefault(require("node:fs/promises"));
const node_path_1 = __importDefault(require("node:path"));
const ts_morph_1 = require("ts-morph");
const isFile = async (filePath) => {
    try {
        const stats = await promises_1.default.stat(filePath);
        return stats.isFile();
    }
    catch {
        return false;
    }
};
const findFile = async (cwd, fileName) => {
    const filePath = node_path_1.default.join(cwd, fileName);
    if (await isFile(filePath))
        return filePath;
    return findFile(node_path_1.default.resolve(cwd, '..'), fileName);
};
const resolvePaths = (cwd, patterns) => {
    return [patterns].flat().map(pattern => {
        if (pattern.startsWith('!'))
            return '!' + node_path_1.default.join(cwd, pattern.slice(1));
        return node_path_1.default.join(cwd, pattern);
    });
};
const createProject = async (cwd, paths) => {
    const tsConfigFilePath = await findFile(cwd, 'tsconfig.json');
    const workspace = new ts_morph_1.Project({
        tsConfigFilePath,
        skipAddingFilesFromTsConfig: true,
        skipFileDependencyResolution: true,
    });
    if (paths)
        workspace.addSourceFilesAtPaths(resolvePaths(cwd, paths));
    return workspace;
};
exports.createProject = createProject;
const partitionSourceFiles = (projectFiles, productionFiles) => {
    const productionFilePaths = productionFiles.map(file => file.getFilePath());
    const usedFiles = [];
    const unusedFiles = [];
    projectFiles.forEach(projectFile => {
        if (productionFilePaths.includes(projectFile.getFilePath())) {
            usedFiles.push(projectFile);
        }
        else {
            unusedFiles.push(projectFile);
        }
    });
    return [usedFiles, unusedFiles];
};
exports.partitionSourceFiles = partitionSourceFiles;
const getType = (declaration) => {
    if (declaration.isKind(ts_morph_1.ts.SyntaxKind.TypeAliasDeclaration))
        return 'type';
    if (declaration.isKind(ts_morph_1.ts.SyntaxKind.InterfaceDeclaration))
        return 'interface';
    if (declaration.isKind(ts_morph_1.ts.SyntaxKind.EnumDeclaration))
        return 'enum';
};
exports.getType = getType;
