"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveIncludedFromArgs = exports.resolveConfig = exports.importConfig = void 0;
const node_path_1 = __importDefault(require("node:path"));
const micromatch_1 = __importDefault(require("micromatch"));
const importConfig = (cwd, configArg) => {
    try {
        const manifest = require(node_path_1.default.join(cwd, 'package.json'));
        if ('knip' in manifest)
            return manifest.knip;
        else
            throw new Error('Unable to find `knip` key in package.json');
    }
    catch (error) {
        try {
            return require(node_path_1.default.resolve(configArg));
        }
        catch (error) {
            console.error(`Unable to find configuration at ${node_path_1.default.join(cwd, configArg)}\n`);
        }
    }
};
exports.importConfig = importConfig;
const resolveConfig = (importedConfiguration, cwdArg) => {
    if (cwdArg && !('projectFiles' in importedConfiguration)) {
        const importedConfigKey = Object.keys(importedConfiguration).find(pattern => micromatch_1.default.isMatch(cwdArg, pattern));
        if (importedConfigKey) {
            return importedConfiguration[importedConfigKey];
        }
    }
    if (!cwdArg && (!importedConfiguration.entryFiles || !importedConfiguration.projectFiles)) {
        console.error('Unable to find `entryFiles` and/or `projectFiles` in configuration.');
        console.info('Add it at root level, or use the --cwd argument with a matching configuration.\n');
        return;
    }
    return importedConfiguration;
};
exports.resolveConfig = resolveConfig;
const resolveIncludedFromArgs = (onlyArg, excludeArg) => {
    const groups = ['files', 'exports', 'types', 'nsExports', 'nsTypes', 'duplicates'];
    const only = onlyArg.map(value => value.split(',')).flat();
    const exclude = excludeArg.map(value => value.split(',')).flat();
    const includes = (only.length > 0 ? only : groups).filter((group) => !exclude.includes(group));
    return groups.reduce((r, group) => ((r[group] = includes.includes(group)), r), {});
};
exports.resolveIncludedFromArgs = resolveIncludedFromArgs;
